SPI

Struct SPI 

pub struct SPI<Miso, Mosi, Sck, Timer>
where Miso: InputPin, Mosi: OutputPin, Sck: OutputPin, Timer: CountDown + Periodic,
{ /* private fields */ }
A Full-Duplex SPI implementation, takes 3 pins, and a timer running at 2x the desired SPI frequency.

Implementations

Source

impl<Miso, Mosi, Sck, Timer, E> SPI<Miso, Mosi, Sck, Timer>
where Miso: InputPin<Error = E>, Mosi: OutputPin<Error = E>, Sck: OutputPin<Error = E>, Timer: CountDown + Periodic,

pub fn new(mode: Mode, miso: Miso, mosi: Mosi, sck: Sck, timer: Timer) -> Self

Create instance

pub fn set_bit_order(&mut self, order: BitOrder)

Set transmission bit order

pub fn access_timer<F>(&mut self, f: F)
where F: FnOnce(Timer) -> Timer,

Allows for an access to the timer type. This can be used to change the speed.

In closure you get ownership of the timer so you can destruct it and build it up again if necessary.

Example
spi.access_timer(|mut timer| {
   timer.set_freq(4.mhz());
   timer
});